@@ -195,7 +195,7 @@ class StableDiffusionControlNetSegGenerator:
 
         return self.pipe
 
-    def controlnet_seg(image_path: str):
+    def controlnet_seg(self, image_path: str):
         image_processor = AutoImageProcessor.from_pretrained(
             "openmmlab/upernet-convnext-small"
         )
@@ -270,13 +270,13 @@ class StableDiffusionControlNetSegGenerator:
 
                     controlnet_seg_prompt = gr.Textbox(
                         lines=1,
-                        label="Prompt",
+                        show_label=False,
                         placeholder="Prompt",
                     )
 
                     controlnet_seg_negative_prompt = gr.Textbox(
                         lines=1,
-                        label="Negative Prompt",
+                        show_label=False,
                         placeholder="Negative Prompt",
                     )
 
